@@ -12,6 +12,7 @@ use List::Util qw/max/;
 
 our $VERSION = '0.0.1';
 
+my $CODESET = eval { I18N::Langinfo::CODESET() };
 my %seen;           # hash of hashes keyed by 'caller', then opt/arg name
 my %opts;           # option configuration keyed by 'caller'
 my %args;           # argument configuration keyed by 'caller'
@@ -311,18 +312,23 @@ sub _optargs {
     my $package = $caller;
 
     if ( !@_ and @ARGV ) {
-        use Data::Dumper;
-        warn Dumper(\@ARGV, [ map {Encode::is_utf8($_)} @ARGV]);
-        my $codeset = eval { langinfo( I18N::Langinfo::CODESET() ) };
-        if ( !$@ ) {
+        my $codeset;
+
+        if ($CODESET) {
+            $codeset = langinfo($CODESET);
+        }
+        elsif ( eval { require POSIX; 1; } ) {
+
+            # just a guess really - worse than nothing at all?
+            $codeset = POSIX::setlocale( eval "POSIX::LC_CTYPE" );
+            $codeset =~ s/.*\.//;
+        }
+
+        if ($codeset) {
             @ARGV =
               map { Encode::is_utf8($_) ? $_ : decode( $codeset, $_ ) } @ARGV;
         }
-        else {
 
-            # our best attempt?
-            @ARGV = map { Encode::is_utf8($_) ? $_ : decode_utf8($_) } @ARGV;
-        }
         $source = \@ARGV;
     }
 
